# eric7.EricNetwork.EricNetworkIcon

Module implementing a statusbar icon tracking the network status.

### Global Attributes

None

### Classes

EricNetworkIcon | Class implementing a statusbar icon tracking the network status.

### Functions

None

## EricNetworkIcon

Class implementing a statusbar icon tracking the network status.

### Signals

onlineStateChanged(online)
  emitted to indicate a change of the network state
reachabilityStateChanged(reachability)
  emitted to indicate a change of the network reachability

### Derived from

QLabel

### Class Attributes

None

### Class Methods

None

### Methods

EricNetworkIcon | Constructor
__reachabilityChanged | Private slot handling reachability state changes.
isOnline | Public method to get the online state.

### Static Methods

None

#### EricNetworkIcon (Constructor)

EricNetworkIcon(dynamicOnlineCheck=True, parent=None)

Constructor

dynamicOnlineCheck (bool (optional))
  flag indicating to perform online checks during runtime (defaults to True)
parent (QWidget)
  reference to the parent widget

#### EricNetworkIcon.__reachabilityChanged

__reachabilityChanged(reachability)

Private slot handling reachability state changes.

reachability (QNetworkInformation.Reachability)
  new reachability state

#### EricNetworkIcon.isOnline

isOnline()

Public method to get the online state.

Return:
  online state

Return Type:
  bool

Up